#!/usr/bin/env python

import argparse
import json
import os
import copy

#from autosubmit.config.basicConfig import BasicConfig
#from autosubmit.config.config_common import AutosubmitConfig
#from bscearth.utils.config_parser import ConfigParserFactory
#from bscearth.utils.date import parse_date, add_time, date2str


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--projdir", type=str)
    parser.add_argument("--template_name", type=str)
    parser.add_argument("--expid", type=str)
    parser.add_argument("--cmor_exp", type=str)
    parser.add_argument("--cmor_add_startdate", type=str)
    parser.add_argument("--startdate", type=str)
    args = parser.parse_args()

    projdir = args.projdir
    template_name = args.template_name
    expid = args.expid
    cmor_exp = args.cmor_exp
    cmor_add_startdate = args.cmor_add_startdate
    startdate = args.startdate

    cv_file = os.path.join(
        projdir , 
        "ece2cmor/ece2cmor3/resources/tables/CMIP6_CV.json"
    )
    if not cmor_exp or cmor_exp == expid:
        cmor_exp = expid

    with open(cv_file, 'r') as cv_file_handler:
        cv_json = json.load(cv_file_handler)
    experiments = cv_json['CV']['experiment_id']
    sub_experiments = cv_json['CV']['sub_experiment_id']


    if template_name == "nemo3":
      required_model_components = [u'OGCM']
    elif template_name == "ifs3":
      required_model_components = [u'AGCM']
    else:
      required_model_components = [u'AOGCM']

    if cmor_exp in experiments:
        experiment_desc = experiments[cmor_exp]
    else:
        experiment_desc = {
            u'activity_id': [u'CMIP'],
            u'parent_experiment_id': [u'none'], 
            u'parent_activity_id': [u'CMIP'], 
            u'experiment': cmor_exp, 
            u'additional_allowed_model_components': [u'AER', u'CHEM', u'BGC'], 
            u'required_model_components': required_model_components ,
            u'experiment_id': cmor_exp, 
            u'sub_experiment_id': [u'none']
        }

    if cmor_add_startdate.lower() in ('true', 't', 'yes'):
        desc = "initialized at {0}".format(startdate)
        sub_experiments['s' + startdate] = desc
        experiment_desc['sub_experiment_id'].append('s' + startdate )
#        experiment_desc['sub_experiment_id'] = [ 's' + startdate ]

    experiments[cmor_exp] = experiment_desc

    with open(cv_file, 'w') as cv_file_handler:
        json.dump(cv_json, cv_file_handler, indent=4, sort_keys=True)

if __name__ == '__main__':
    main()
